#[non_exhaustive]pub enum XmlError {
Malformed(String),
BadId(String),
InvalidScalar {
kind: String,
value: String,
},
UnknownKind(String),
DuplicateSlot {
name: String,
slot: usize,
},
MissingSlot {
name: String,
slot: usize,
missing: usize,
},
Namespace {
element: String,
expected: &'static str,
found: Option<String>,
},
Profile {
expected: &'static str,
found: Option<String>,
},
Root {
found: Option<String>,
},
At {
path: XmlPath,
source: Box<XmlError>,
},
Write(String),
}Expand description
Failures specific to reading or writing ifcXML.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Malformed(String)
The document is not well-formed XML.
BadId(String)
An id attribute was not in the expected i<number> form.
InvalidScalar
A typed scalar did not contain a value of its declared kind.
UnknownKind(String)
A non-empty explicit kind is not part of this lossless dialect.
DuplicateSlot
Two attributes or child elements of one entity name the same slot.
Fields
MissingSlot
A positional name skips slots that no schema declares as omittable.
Fields
Namespace
An element resolved outside the selected release namespace.
Fields
Profile
Root schema metadata disagrees with the selected release profile.
Fields
Root
A strict document did not have the required root element.
At
A parsing error with its entity/value location retained.
Write(String)
Writing to the output buffer failed.
Implementations